SafeDevice class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
isDevelopmentModeEnable
→ Future<
bool> -
no setter
- isInitiated ↔ bool
-
getter/setter pair
-
isJailBroken
→ Future<
bool> -
no setter
-
isJailBrokenCustom
→ Future<
bool> -
no setter
-
isMockLocation
→ Future<
bool> -
no setter
-
isOnExternalStorage
→ Future<
bool> -
no setter
-
isRealDevice
→ Future<
bool> -
no setter
-
isSafeDevice
→ Future<
bool> -
no setter
-
isUsbDebuggingEnabled
→ Future<
bool> -
no setter
-
jailbreakDetails
→ Future<
Map< String, dynamic> > -
no setter
-
rootDetectionDetails
→ Future<
Map< String, dynamic> > -
Get detailed root detection results for Android only
This provides a breakdown of all detection methods for debugging
Returns empty map on iOS devices
no setter
Static Methods
-
ensureInitiated(
) → void -
init(
SafeDeviceConfig config) → void